@@ -16,6 +16,7 @@ use namespace::autoclean 0.16;
 use autodie;
 
 use YAML::XS;
+use List::MoreUtils qw(uniq);
 use Hash::Merge qw(merge);
 use Try::Tiny;
 
@@ -34,11 +35,11 @@ no warnings "experimental::signatures";
 
 =head1 VERSION
 
-Version v1.4.1
+Version v1.4.3
 
 =cut
 
-our $VERSION = "v1.4.1";
+our $VERSION = "v1.4.3";
 
 =head1 DESCRIPTION
 
@@ -95,6 +96,26 @@ has parts => (
 	init_arg => undef,
 );
 
+# process only matching types, and skip duplicates is arrays
+my $merge_spec = {
+	'SCALAR' => {
+		'SCALAR' => sub { $_[0] },
+		'ARRAY'  => sub { die 'bad input data' },
+		'HASH'   => sub { die 'bad input data' },
+	},
+	'ARRAY' => {
+		'SCALAR' => sub { die 'bad input data' },
+		'ARRAY'  => sub { [ uniq @{ $_[0] }, @{ $_[1] } ] },
+		'HASH'   => sub { die 'bad input data' },
+	},
+	'HASH' => {
+		'SCALAR' => sub { die 'bad input data' },
+		'ARRAY'  => sub { die 'bad input data' },
+		'HASH'   => sub { Hash::Merge::_merge_hashes( $_[0], $_[1] ) },
+	},
+};
+Hash::Merge::add_behavior_spec($merge_spec);
+
 sub _build_parts ($self)
 {
 	my $classdata = $self->classdir->visit(
@@ -119,8 +140,11 @@ sub _build_parts ($self)
 	);
 	my @parts;
 	for ( sort keys %{$nodedata} ) {
-		my %params  = $nodedata->{$_}{parameters} || ();
-		my @classes = @{ $nodedata->{$_}{classes} };
+		my %params = ();
+		my @classes
+			= $nodedata->{$_}{classes}
+			? @{ $nodedata->{$_}{classes} }
+			: ();
 		while ( my $next = shift @classes ) {
 			unless ( $classdata->{$next} ) {
 				$self->_logger->debug(
